@@ -19,7 +19,7 @@ int Archive::SearchBlock(int BlockType)
 int Archive::SearchSubBlock(const char *Type)
 {
   int Size;
-  while ((Size=ReadHeader())!=0)
+  while ((Size=ReadHeader())!=0 && GetHeaderType()!=ENDARC_HEAD)
   {
     if (GetHeaderType()==NEWSUB_HEAD && SubHead.CmpName(Type))
       return(Size);
@@ -121,6 +121,8 @@ int Archive::ReadHeader()
       *(BaseBlock *)&EndArcHead=ShortBlock;
       if (EndArcHead.Flags & EARC_DATACRC)
         Raw.Get(EndArcHead.ArcDataCRC);
+      if (EndArcHead.Flags & EARC_VOLNUMBER)
+        Raw.Get(EndArcHead.VolNumber);
       break;
     case FILE_HEAD:
     case NEWSUB_HEAD:
@@ -142,7 +144,14 @@ int Archive::ReadHeader()
           Raw.Get(hd->HighUnpSize);
         }
         else 
+        {
           hd->HighPackSize=hd->HighUnpSize=0;
+          if (hd->UnpSize==0xffffffff)
+          {
+            hd->UnpSize=int64to32(INT64MAX);
+            hd->HighUnpSize=(INT64MAX>>32);
+          }
+        }
         hd->FullPackSize=int32to64(hd->HighPackSize,hd->PackSize);
         hd->FullUnpSize=int32to64(hd->HighUnpSize,hd->UnpSize);
 
@@ -292,6 +301,10 @@ int Archive::ReadHeader()
           *(SubBlockHeader *)&UOHead=SubBlockHead;
           Raw.Get(UOHead.OwnerNameSize);
           Raw.Get(UOHead.GroupNameSize);
+          if (UOHead.OwnerNameSize>NM-1)
+            UOHead.OwnerNameSize=NM-1;
+          if (UOHead.GroupNameSize>NM-1)
+            UOHead.GroupNameSize=NM-1;
           Raw.Get((byte *)UOHead.OwnerName,UOHead.OwnerNameSize);
           Raw.Get((byte *)UOHead.GroupName,UOHead.GroupNameSize);
           UOHead.OwnerName[UOHead.OwnerNameSize]=0;
@@ -318,6 +331,8 @@ int Archive::ReadHeader()
           Raw.Get(StreamHead.Method);
           Raw.Get(StreamHead.StreamCRC);
           Raw.Get(StreamHead.StreamNameSize);
+          if (StreamHead.StreamNameSize>NM-1)
+            StreamHead.StreamNameSize=NM-1;
           Raw.Get((byte *)StreamHead.StreamName,StreamHead.StreamNameSize);
           StreamHead.StreamName[StreamHead.StreamNameSize]=0;
           break;
@@ -358,7 +373,11 @@ int Archive::ReadHeader()
         Log(FileName,St(MEncrBadCRC),FileName);
 #endif
         Close();
-        ErrHandler.Exit(CRC_ERROR);
+
+        BrokenFileHeader=true;
+        ErrHandler.SetErrorCode(CRC_ERROR);
+        return(0);
+//        ErrHandler.Exit(CRC_ERROR);
       }
     }
   }
@@ -424,7 +443,7 @@ int Archive::ReadOldHeader()
       NextBlockPos=CurBlockPos+NewLhd.HeadSize+NewLhd.PackSize;
     CurHeaderType=FILE_HEAD;
   }
-  return(Raw.Size());
+  return(NextBlockPos>CurBlockPos ? Raw.Size():0);
 }
 #endif
 
@@ -465,7 +484,7 @@ bool Archive::IsArcDir()
 
 bool Archive::IsArcLabel()
 {
-  return(NewLhd.HostOS<=WIN_32 && (NewLhd.FileAttr & 8));
+  return(NewLhd.HostOS<=HOST_WIN32 && (NewLhd.FileAttr & 8));
 }
 
 
@@ -474,12 +493,12 @@ void Archive::ConvertAttributes()
 #if defined(_WIN_32) || defined(_EMX)
   switch(NewLhd.HostOS)
   {
-    case MS_DOS:
-    case OS2:
-    case WIN_32:
+    case HOST_MSDOS:
+    case HOST_OS2:
+    case HOST_WIN32:
       break;
-    case UNIX:
-    case BEOS:
+    case HOST_UNIX:
+    case HOST_BEOS:
       if ((NewLhd.Flags & LHD_WINDOWMASK)==LHD_DIRECTORY)
         NewLhd.FileAttr=0x10;
       else
@@ -503,9 +522,9 @@ void Archive::ConvertAttributes()
   }
   switch(NewLhd.HostOS)
   {
-    case MS_DOS:
-    case OS2:
-    case WIN_32:
+    case HOST_MSDOS:
+    case HOST_OS2:
+    case HOST_WIN32:
       if (NewLhd.FileAttr & 0x10)
         NewLhd.FileAttr=0x41ff & ~mask;
       else
@@ -514,8 +533,8 @@ void Archive::ConvertAttributes()
         else
           NewLhd.FileAttr=0x81b6 & ~mask;
       break;
-    case UNIX:
-    case BEOS:
+    case HOST_UNIX:
+    case HOST_BEOS:
       break;
     default:
       if ((NewLhd.Flags & LHD_WINDOWMASK)==LHD_DIRECTORY)
@@ -532,7 +551,7 @@ void Archive::ConvertUnknownHeader()
 {
   if (NewLhd.UnpVer<20 && (NewLhd.FileAttr & 0x10))
     NewLhd.Flags|=LHD_DIRECTORY;
-  if (NewLhd.HostOS>BEOS)
+  if (NewLhd.HostOS>=HOST_MAX)
   {
     if ((NewLhd.Flags & LHD_WINDOWMASK)==LHD_DIRECTORY)
       NewLhd.FileAttr=0x10;
@@ -588,7 +607,6 @@ bool Archive::ReadSubData(Array<byte> *UnpData,File *DestFile)
   if (SubHead.PackSize==0 && (SubHead.Flags & LHD_SPLIT_AFTER)==0)
     return(true);
 
-//  ComprDataIO DataIO(NULL);
   SubDataIO.Init();
   Unpack Unpack(&SubDataIO);
   Unpack.Init();
