@@ -1,6 +1,6 @@
 #include "rar.hpp"
 
-CmdExtract::CmdExtract():DataIO(NULL)
+CmdExtract::CmdExtract()
 {
   TotalFileCount=0;
   *Password=0;
@@ -93,6 +93,9 @@ EXTRACT_ARC_CODE CmdExtract::ExtractArchive(CommandData *Cmd)
     return(EXTRACT_ARC_NEXT);
   }
 
+  if (!Arc.IsOpened())
+    return(EXTRACT_ARC_NEXT);
+
 #ifndef SFX_MODULE
   if (Arc.Volume && Arc.NotFirstVolume)
   {
@@ -161,7 +164,7 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
   {
     if (HeadType==AV_HEAD || HeadType==SIGN_HEAD)
       SignatureFound=true;
-#ifndef SFX_MODULE
+#if !defined(SFX_MODULE) && !defined(_WIN_CE)
     if (HeadType==SUB_HEAD && PrevExtracted)
       SetExtraInfo(Cmd,Arc,DestFileName,*DestFileNameW ? DestFileNameW:NULL);
 #endif
@@ -169,7 +172,7 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
     {
       if (Arc.SubHead.CmpName(SUBHEAD_TYPE_AV))
         SignatureFound=true;
-#ifndef NOSUBBLOCKS
+#if !defined(NOSUBBLOCKS) && !defined(_WIN_CE)
       if (PrevExtracted)
         SetExtraInfoNew(Cmd,Arc,DestFileName,*DestFileNameW ? DestFileNameW:NULL);
 #endif
@@ -208,11 +211,28 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
   *ArcFileNameW=0;
 
   bool EqualNames=false;
-  bool ExactMatch=Cmd->IsProcessFile(Arc.NewLhd,&EqualNames);
+  int MatchNumber=Cmd->IsProcessFile(Arc.NewLhd,&EqualNames);
+  bool ExactMatch=MatchNumber!=0;
+#if !defined(SFX_MODULE) && !defined(_WIN_CE)
+  if (Cmd->ExclPath==EXCL_BASEPATH)
+  {
+    *Cmd->ArcPath=0;
+    if (ExactMatch)
+    {
+      Cmd->FileArgs->Rewind();
+      if (Cmd->FileArgs->GetString(Cmd->ArcPath,NULL,sizeof(Cmd->ArcPath),MatchNumber-1))
+        *PointToName(Cmd->ArcPath)=0;
+    }
+  }
+#endif
   if (ExactMatch && !EqualNames)
     AllMatchesExact=false;
 
-  bool WideName=(Arc.NewLhd.Flags & LHD_UNICODE);
+#ifdef UNICODE_SUPPORTED
+  bool WideName=(Arc.NewLhd.Flags & LHD_UNICODE) && UnicodeEnabled();
+#else
+  bool WideName=false;
+#endif
 
 #ifdef _APPLE
   if (WideName)
@@ -268,10 +288,11 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
     VolNameToFirstName(ArcName,ArcName,(Arc.NewMhd.Flags & MHD_NEWNUMBERING));
     if (stricomp(ArcName,CurVolName)!=0 && FileExist(ArcName))
     {
+      *ArcNameW=0;
       Repeat=true;
       return(false);
     }
-#ifndef RARDLL
+#if !defined(RARDLL) && !defined(_WIN_CE)
     if (!ReconstructDone)
     {
       ReconstructDone=true;
@@ -355,7 +376,13 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
         }
 #endif
 
-    strcpy(DestFileName,Cmd->ExtrPath);
+#ifndef SFX_MODULE
+    if (*Cmd->ExtrPath==0 && *Cmd->ExtrPathW!=0)
+      WideToChar(Cmd->ExtrPathW,DestFileName);
+    else
+#endif
+      strcpy(DestFileName,Cmd->ExtrPath);
+
 
 #ifndef SFX_MODULE
     if (Cmd->AppendArcNameToPath)
@@ -378,19 +405,43 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
     }
 #endif
 
+    bool AbsPaths=Cmd->ExclPath==EXCL_ABSPATH && Command=='X' && IsDriveDiv(':');
+    if (AbsPaths)
+      *DestFileName=0;
+
     if (Command=='E' || Cmd->ExclPath==EXCL_SKIPWHOLEPATH)
       strcat(DestFileName,PointToName(ExtrName));
     else
       strcat(DestFileName,ExtrName);
 
+    if (AbsPaths && DestFileName[1]=='_' && IsPathDiv(DestFileName[2]))
+      DestFileName[1]=':';
+
+#ifndef SFX_MODULE
+    if (!WideName && *Cmd->ExtrPathW!=0)
+    {
+      DestNameW=DestFileNameW;
+      WideName=true;
+      CharToWide(ArcFileName,ArcFileNameW);
+    }
+#endif
+
     if (WideName)
     {
-      CharToWide(Cmd->ExtrPath,DestFileNameW);
+      if (*Cmd->ExtrPathW!=0)
+        strcpyw(DestFileNameW,Cmd->ExtrPathW);
+      else
+        CharToWide(Cmd->ExtrPath,DestFileNameW);
 
 #ifndef SFX_MODULE
       if (Cmd->AppendArcNameToPath)
       {
-        strcatw(DestFileNameW,PointToName(Arc.FileNameW));
+        wchar FileNameW[NM];
+        if (*Arc.FileNameW!=0)
+          strcpyw(FileNameW,Arc.FileNameW);
+        else
+          CharToWide(Arc.FileName,FileNameW);
+        strcatw(DestFileNameW,PointToName(FileNameW));
         SetExt(DestFileNameW,NULL);
         AddEndSlash(DestFileNameW);
       }
@@ -408,10 +459,16 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
         ExtrNameW++;
 #endif
 
+      if (AbsPaths)
+        *DestFileNameW=0;
+
       if (Command=='E' || Cmd->ExclPath==EXCL_SKIPWHOLEPATH)
         strcatw(DestFileNameW,PointToName(ExtrNameW));
       else
         strcatw(DestFileNameW,ExtrNameW);
+
+      if (AbsPaths && DestFileNameW[1]=='_' && IsPathDiv(DestFileNameW[2]))
+        DestFileNameW[1]=':';
     }
     else
       *DestFileNameW=0;
@@ -438,6 +495,13 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
       if (Cmd->DllOpMode!=RAR_EXTRACT)
         ExtrFile=false;
     }
+    if (*Cmd->DllDestNameW)
+    {
+      strncpyw(DestFileNameW,Cmd->DllDestNameW,sizeof(DestFileNameW)/sizeof(DestFileNameW[0]));
+      DestNameW=DestFileNameW;
+      if (Cmd->DllOpMode!=RAR_EXTRACT)
+        ExtrFile=false;
+    }
 #endif
 
 #ifdef SFX_MODULE
@@ -520,7 +584,17 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
             ErrHandler.SetErrorCode(CREATE_ERROR);
           }
         if (PrevExtracted)
-          SetDirTime(DestFileName,&Arc.NewLhd.mtime,&Arc.NewLhd.ctime,&Arc.NewLhd.atime);
+        {
+#if defined(_WIN_32) && !defined(_WIN_CE) && !defined(SFX_MODULE)
+          if (Cmd->SetCompressedAttr &&
+              (Arc.NewLhd.FileAttr & FILE_ATTRIBUTE_COMPRESSED)!=0 && WinNT())
+            SetFileCompression(DestFileName,DestFileNameW,true);
+#endif
+          SetDirTime(DestFileName,
+            Cmd->xmtime==EXTTIME_NONE ? NULL:&Arc.NewLhd.mtime,
+            Cmd->xctime==EXTTIME_NONE ? NULL:&Arc.NewLhd.ctime,
+            Cmd->xatime==EXTTIME_NONE ? NULL:&Arc.NewLhd.atime);
+        }
         return(true);
       }
       else
@@ -539,8 +613,11 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
             ExtrFile=false;
             if (!UserReject)
             {
-              ErrHandler.CreateErrorMsg(DestFileName);
+              ErrHandler.CreateErrorMsg(Arc.FileName,DestFileName);
               ErrHandler.SetErrorCode(CREATE_ERROR);
+#ifdef RARDLL
+              Cmd->DllError=ERAR_ECREATE;
+#endif
               if (!IsNameUsable(DestFileName))
               {
                 Log(Arc.FileName,St(MCorrectingName));
@@ -549,12 +626,7 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
                 if (FileCreate(Cmd,&CurFile,DestFileName,NULL,Cmd->Overwrite,&UserReject,Arc.NewLhd.FullUnpSize,Arc.NewLhd.FileTime))
                   ExtrFile=true;
                 else
-                {
-                  ErrHandler.CreateErrorMsg(DestFileName);
-#ifdef RARDLL
-                  Cmd->DllError=ERAR_ECREATE;
-#endif
-                }
+                  ErrHandler.CreateErrorMsg(Arc.FileName,DestFileName);
               }
             }
           }
@@ -574,7 +646,7 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
         if (!TestMode && Command!='P' && CurFile.IsDevice())
         {
           Log(Arc.FileName,St(MInvalidName),DestFileName);
-          ErrHandler.WriteError(DestFileName);
+          ErrHandler.WriteError(Arc.FileName,DestFileName);
         }
         TotalFileCount++;
       }
@@ -613,8 +685,12 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
       DataIO.SetFiles(&Arc,&CurFile);
       DataIO.SetTestMode(TestMode);
       DataIO.SetSkipUnpCRC(SkipSolid);
-      if (!TestMode && Arc.NewLhd.FullUnpSize>0x1000)
+#ifndef _WIN_CE
+      if (!TestMode && !Arc.BrokenFileHeader &&
+          (Arc.NewLhd.FullPackSize<<11)>Arc.NewLhd.FullUnpSize &&
+          (Arc.NewLhd.FullUnpSize<100000000 || Arc.FileLength()>Arc.NewLhd.FullPackSize))
         CurFile.Prealloc(Arc.NewLhd.FullUnpSize);
+#endif
 
       CurFile.SetAllowDelete(!Cmd->KeepBroken);
 
@@ -639,8 +715,8 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
       bool BrokenFile=false;
       if (!SkipSolid)
       {
-        if (Arc.OldFormat && DataIO.UnpFileCRC==Arc.NewLhd.FileCRC ||
-            !Arc.OldFormat && DataIO.UnpFileCRC==(Arc.NewLhd.FileCRC^0xffffffff))
+        if (Arc.OldFormat && UINT32(DataIO.UnpFileCRC)==UINT32(Arc.NewLhd.FileCRC) ||
+            !Arc.OldFormat && UINT32(DataIO.UnpFileCRC)==UINT32(Arc.NewLhd.FileCRC^0xffffffff))
         {
 #ifndef GUI
           if (Command!='P' && Command!='I')
@@ -687,6 +763,11 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,int HeaderSize
             Cmd->xctime==EXTTIME_NONE ? NULL:&Arc.NewLhd.ctime,
             Cmd->xatime==EXTTIME_NONE ? NULL:&Arc.NewLhd.atime);
           CurFile.Close();
+#if defined(_WIN_32) && !defined(_WIN_CE) && !defined(SFX_MODULE)
+          if (Cmd->SetCompressedAttr &&
+              (Arc.NewLhd.FileAttr & FILE_ATTRIBUTE_COMPRESSED)!=0 && WinNT())
+            SetFileCompression(CurFile.FileName,CurFile.FileNameW,true);
+#endif
           CurFile.SetCloseFileStat(
             Cmd->xmtime==EXTTIME_NONE ? NULL:&Arc.NewLhd.mtime,
             Cmd->xatime==EXTTIME_NONE ? NULL:&Arc.NewLhd.atime,
