@@ -106,6 +106,9 @@ bool FindFile::Next(struct FindData *fd,bool GetSymLink)
 #ifdef _APPLE
   if (!LowAscii(fd->Name))
     UtfToWide(fd->Name,fd->NameW,sizeof(fd->NameW));
+#elif defined(UNICODE_SUPPORTED)
+  if (!LowAscii(fd->Name) && UnicodeEnabled())
+    CharToWide(fd->Name,fd->NameW);
 #endif
 #endif
   fd->IsDir=IsDir(fd->FileAttr);
@@ -163,10 +166,14 @@ bool FindFile::FastFind(const char *FindMask,const wchar *FindMaskW,struct FindD
   fd->ctime=st.st_ctime;
   fd->FileTime=fd->mtime.GetDos();
   strcpy(fd->Name,FindMask);
+
   *fd->NameW=0;
 #ifdef _APPLE
   if (!LowAscii(fd->Name))
     UtfToWide(fd->Name,fd->NameW,sizeof(fd->NameW));
+#elif defined(UNICODE_SUPPORTED)
+  if (!LowAscii(fd->Name) && UnicodeEnabled())
+    CharToWide(fd->Name,fd->NameW);
 #endif
 #endif
   fd->IsDir=IsDir(fd->FileAttr);
@@ -177,7 +184,9 @@ bool FindFile::FastFind(const char *FindMask,const wchar *FindMaskW,struct FindD
 #ifdef _WIN_32
 HANDLE FindFile::Win32Find(HANDLE hFind,const char *Mask,const wchar *MaskW,struct FindData *fd)
 {
+#ifndef _WIN_CE
   if (WinNT())
+#endif
   {
     wchar WideMask[NM];
     if (MaskW!=NULL && *MaskW!=0)
@@ -192,7 +201,9 @@ HANDLE FindFile::Win32Find(HANDLE hFind,const char *Mask,const wchar *MaskW,stru
       if (hFind==INVALID_HANDLE_VALUE)
       {
         int SysErr=GetLastError();
-        fd->Error=(SysErr!=ERROR_FILE_NOT_FOUND && SysErr!=ERROR_PATH_NOT_FOUND);
+        fd->Error=(SysErr!=ERROR_FILE_NOT_FOUND &&
+                   SysErr!=ERROR_PATH_NOT_FOUND &&
+                   SysErr!=ERROR_NO_MORE_FILES);
       }
     }
     else
@@ -217,10 +228,13 @@ HANDLE FindFile::Win32Find(HANDLE hFind,const char *Mask,const wchar *MaskW,stru
       fd->atime=FindData.ftLastAccessTime;
       fd->FileTime=fd->mtime.GetDos();
 
+#ifndef _WIN_CE
       if (LowAscii(fd->NameW))
         *fd->NameW=0;
+#endif
     }
   }
+#ifndef _WIN_CE
   else
   {
     char CharMask[NM];
@@ -260,11 +274,11 @@ HANDLE FindFile::Win32Find(HANDLE hFind,const char *Mask,const wchar *MaskW,stru
       fd->ctime=FindData.ftCreationTime;
       fd->atime=FindData.ftLastAccessTime;
       fd->FileTime=fd->mtime.GetDos();
-
       if (LowAscii(fd->Name))
         *fd->NameW=0;
     }
   }
+#endif
   return(hFind);
 }
 #endif
