@@ -1,6 +1,7 @@
 #include "rar.hpp"
 
 static void ListFileHeader(FileHeader &hd,bool Verbose,bool Technical,bool &TitleShown,bool Bare);
+static void ListSymLink(Archive &Arc);
 static void ListFileAttr(uint A,int HostOS);
 static void ListOldSubHeader(Archive &Arc);
 static void ListNewSubHeader(CommandData *Cmd,Archive &Arc,bool Technical);
@@ -28,6 +29,8 @@ void ListArchive(CommandData *Cmd)
       uint FileCount=0;
       if (Arc.IsArchive(true))
       {
+        if (!Arc.IsOpened())
+          break;
         bool TitleShown=false;
         if (!Bare)
         {
@@ -71,6 +74,12 @@ void ListArchive(CommandData *Cmd)
                   FileCount++;
                 }
                 TotalPackSize+=Arc.NewLhd.FullPackSize;
+                if (Technical)
+                  ListSymLink(Arc);
+#ifndef SFX_MODULE
+                if (Verbose)
+                  Arc.ViewFileComment();
+#endif
               }
               break;
 #ifndef SFX_MODULE
@@ -102,11 +111,19 @@ void ListArchive(CommandData *Cmd)
             char PackSizeText[20];
             itoa(TotalPackSize,PackSizeText);
         
-            mprintf("\n%5lu %16s %8s %3d%%\n",FileCount,UnpSizeText,
+            mprintf("\n%5lu %16s %8s %3d%%",FileCount,UnpSizeText,
                     PackSizeText,ToPercent(TotalPackSize,TotalUnpSize));
             SumFileCount+=FileCount;
             SumUnpSize+=TotalUnpSize;
             SumPackSize+=TotalPackSize;
+#ifndef SFX_MODULE
+            if (Arc.EndArcHead.Flags & EARC_VOLNUMBER)
+            {
+              mprintf("       ");
+              mprintf(St(MVolumeNumber),Arc.EndArcHead.VolNumber+1);
+            }
+#endif
+            mprintf("\n");
           }
           else
             mprintf(St(MListNoFiles));
@@ -172,7 +189,7 @@ void ListFileHeader(FileHeader &hd,bool Verbose,bool Technical,bool &TitleShown,
 
 #ifdef UNICODE_SUPPORTED
   char ConvertedName[NM];
-  if ((hd.Flags & LHD_UNICODE)!=0 && *hd.FileNameW!=0)
+  if ((hd.Flags & LHD_UNICODE)!=0 && *hd.FileNameW!=0 && UnicodeEnabled())
   {
     WideToChar(hd.FileNameW,ConvertedName);
     Name=ConvertedName;
@@ -191,7 +208,10 @@ void ListFileHeader(FileHeader &hd,bool Verbose,bool Technical,bool &TitleShown,
     mprintf("%-12s",PointToName(Name));
 
   char UnpSizeText[20],PackSizeText[20];
-  itoa(hd.FullUnpSize,UnpSizeText);
+  if (hd.FullUnpSize==INT64MAX)
+    strcpy(UnpSizeText,"?");
+  else
+    itoa(hd.FullUnpSize,UnpSizeText);
   itoa(hd.FullPackSize,PackSizeText);
 
   mprintf(" %8s %8s ",UnpSizeText,PackSizeText);
@@ -225,7 +245,7 @@ void ListFileHeader(FileHeader &hd,bool Verbose,bool Technical,bool &TitleShown,
   mprintf(" %d.%d",hd.UnpVer/10,hd.UnpVer%10);
 
   static char *RarOS[]={
-    "DOS","OS/2","Win95/NT","Unix","MacOS","BeOS","","","",""
+    "DOS","OS/2","Win95/NT","Unix","MacOS","BeOS","WinCE","","",""
   };
 
   if (Technical)
@@ -235,24 +255,38 @@ void ListFileHeader(FileHeader &hd,bool Verbose,bool Technical,bool &TitleShown,
 }
 
 
+void ListSymLink(Archive &Arc)
+{
+  if (Arc.NewLhd.HostOS==HOST_UNIX && (Arc.NewLhd.FileAttr & 0xF000)==0xA000)
+  {
+    char FileName[NM];
+    int DataSize=Min(Arc.NewLhd.PackSize,sizeof(FileName)-1);
+    Arc.Read(FileName,DataSize);
+    FileName[DataSize]=0;
+    mprintf("\n%22s %s","-->",FileName);
+  }
+}
+
+
 void ListFileAttr(uint A,int HostOS)
 {
   switch(HostOS)
   {
-    case MS_DOS:
-    case OS2:
-    case WIN_32:
-    case MAC_OS:
-      mprintf("  %c%c%c%c%c%c  ",
+    case HOST_MSDOS:
+    case HOST_OS2:
+    case HOST_WIN32:
+    case HOST_MACOS:
+      mprintf(" %c%c%c%c%c%c%c  ",
               (A & 0x08) ? 'V' : '.',
               (A & 0x10) ? 'D' : '.',
               (A & 0x01) ? 'R' : '.',
               (A & 0x02) ? 'H' : '.',
               (A & 0x04) ? 'S' : '.',
-              (A & 0x20) ? 'A' : '.');
+              (A & 0x20) ? 'A' : '.',
+              (A & 0x800) ? 'C' : '.');
       break;
-    case UNIX:
-    case BEOS:
+    case HOST_UNIX:
+    case HOST_BEOS:
       switch (A & 0xF000)
       {
         case 0x4000:
@@ -314,7 +348,7 @@ void ListOldSubHeader(Archive &Arc)
 
 void ListNewSubHeader(CommandData *Cmd,Archive &Arc,bool Technical)
 {
-  if (strcmp(Arc.SubHead.FileName,SUBHEAD_TYPE_CMT)==0 &&
+  if (Arc.SubHead.CmpName(SUBHEAD_TYPE_CMT) &&
       (Arc.SubHead.Flags & LHD_SPLIT_BEFORE)==0 && !Cmd->DisableComment)
   {
     Array<byte> CmtData;
@@ -325,4 +359,18 @@ void ListNewSubHeader(CommandData *Cmd,Archive &Arc,bool Technical)
       OutComment((char *)&CmtData[0],ReadSize);
     }
   }
+  if (Arc.SubHead.CmpName(SUBHEAD_TYPE_STREAM) &&
+      (Arc.SubHead.Flags & LHD_SPLIT_BEFORE)==0)
+  {
+    int DestSize=Arc.SubHead.SubData.Size()/2;
+    wchar DestNameW[NM];
+    char DestName[NM];
+    if (DestSize<sizeof(DestName))
+    {
+      RawToWide(&Arc.SubHead.SubData[0],DestNameW,DestSize);
+      DestNameW[DestSize]=0;
+      WideToChar(DestNameW,DestName);
+      mprintf("\n %s",DestName);
+    }
+  }
 }
