@@ -3,10 +3,10 @@
 #define   MYesNoAllRenQ      "_Yes_No_All_nEver_Rename_Quit"
 #define   MContinueQuit      "_Continue_Quit"
 #define   MRetryAbort        "_Retry_Abort"
-#define   MCopyright         "\nRAR %s    Copyright (c) 1993-%d Eugene Roshal    %d %s %d"
+#define   MCopyright         "\nRAR %s   Copyright (c) 1993-%d Alexander Roshal   %d %s %d"
 #define   MRegTo             "\nRegistered to %s\n"
 #define   MShare             "\nShareware version         Type RAR -? for help\n"
-#define   MUCopyright        "\nUNRAR %s freeware      Copyright (c) 1993-%d Eugene Roshal\n"
+#define   MUCopyright        "\nUNRAR %s freeware      Copyright (c) 1993-%d Alexander Roshal\n"
 #define   MBeta              "beta"
 #define   MMonthJan          "Jan"
 #define   MMonthFeb          "Feb"
@@ -70,6 +70,7 @@
 #define   MCHelpSwEP         "\n  ep            Exclude paths from names"
 #define   MCHelpSwEP1        "\n  ep1           Exclude base directory from names"
 #define   MCHelpSwEP2        "\n  ep2           Expand paths to full"
+#define   MCHelpSwEP3        "\n  ep3           Expand paths to full including the drive letter"
 #define   MCHelpSwF          "\n  f             Freshen files"
 #define   MCHelpSwHP         "\n  hp[password]  Encrypt both file data and headers"
 #define   MCHelpSwIDP        "\n  idp           Disable percentage display"
@@ -87,6 +88,7 @@
 #define   MCHelpSwMS         "\n  ms[ext;ext]   Specify file types to store"
 #define   MCHelpSwOp         "\n  o+            Overwrite existing files"
 #define   MCHelpSwOm         "\n  o-            Do not overwrite existing files"
+#define   MCHelpSwOC         "\n  oc            Set NTFS Compressed attribute"
 #define   MCHelpSwOL         "\n  ol            Save symbolic links as the link instead of the file"
 #define   MCHelpSwOS         "\n  os            Save NTFS streams"
 #define   MCHelpSwOW         "\n  ow            Save or restore file owner and group"
@@ -331,3 +333,5 @@
 #define   MSHelpCmdT         "\n  -t      Test archive files" 
 #define   MSHelpCmdV         "\n  -v      Verbosely list contents of archive" 
 #define   MMaxPathLimit      "\nTotal path and file name length must not exceed %d characters"
+#define   MRecVolLimit       "\nTotal number of usual and recovery volumes must not exceed 255"
+#define   MVolumeNumber      "volume %d"
