@@ -5,8 +5,6 @@ static bool match(wchar *pattern,wchar *string);
 
 inline uint toupperc(byte ch)
 {
-/*
-*/
 #if defined(_WIN_32)
   return((uint)CharUpper((LPTSTR)(ch)));
 #elif defined(_UNIX)
@@ -19,8 +17,6 @@ inline uint toupperc(byte ch)
 
 inline uint touppercw(uint ch)
 {
-/*
-*/
 #if defined(_UNIX)
   return(ch);
 #else
@@ -53,7 +49,7 @@ bool CmpName(char *Wildcard,char *Name,int CmpPath)
       else
         if (CmpPath==MATCH_SUBPATH || IsWildcard(Wildcard))
         {
-          if (strnicompc(Path1,Path2,strlen(Path1))!=0)
+          if (*Path1 && strnicompc(Path1,Path2,strlen(Path1))!=0)
             return(false);
         }
         else
@@ -91,7 +87,7 @@ bool CmpName(wchar *Wildcard,wchar *Name,int CmpPath)
       else
         if (CmpPath==MATCH_SUBPATH || IsWildcard(NULL,Wildcard))
         {
-          if (strnicompcw(Path1,Path2,strlenw(Path1))!=0)
+          if (*Path1 && strnicompcw(Path1,Path2,strlenw(Path1))!=0)
             return(false);
         }
         else
@@ -207,8 +203,6 @@ bool match(wchar *pattern,wchar *string)
 
 int stricompc(const char *Str1,const char *Str2)
 {
-/*
-*/
 #if defined(_UNIX)
   return(strcmp(Str1,Str2));
 #else
@@ -220,8 +214,6 @@ int stricompc(const char *Str1,const char *Str2)
 #ifndef SFX_MODULE
 int stricompcw(const wchar *Str1,const wchar *Str2)
 {
-/*
-*/
 #if defined(_UNIX)
   return(strcmpw(Str1,Str2));
 #else
@@ -233,8 +225,6 @@ int stricompcw(const wchar *Str1,const wchar *Str2)
 
 int strnicompc(const char *Str1,const char *Str2,int N)
 {
-/*
-*/
 #if defined(_UNIX)
   return(strncmp(Str1,Str2,N));
 #else
@@ -246,8 +236,6 @@ int strnicompc(const char *Str1,const char *Str2,int N)
 #ifndef SFX_MODULE
 int strnicompcw(const wchar *Str1,const wchar *Str2,int N)
 {
-/*
-*/
 #if defined(_UNIX)
   return(strncmpw(Str1,Str2,N));
 #else
