@@ -6,7 +6,8 @@
 #define DEFAULT_RECVOLUMES  -10
 
 enum PathExclMode {
-  EXCL_NONE,EXCL_BASEPATH,EXCL_SKIPWHOLEPATH,EXCL_SAVEFULLPATH,EXCL_SKIPABSPATH
+  EXCL_NONE,EXCL_BASEPATH,EXCL_SKIPWHOLEPATH,EXCL_SAVEFULLPATH,
+  EXCL_SKIPABSPATH,EXCL_ABSPATH
 };
 enum {SOLID_NONE=0,SOLID_NORMAL=1,SOLID_COUNT=2,SOLID_FILEEXT=4,
       SOLID_VOLUME_DEPENDENT=8,SOLID_VOLUME_INDEPENDENT=16};
@@ -41,6 +42,7 @@ class RAROptions
     char TempPath[NM];
     char SFXModule[NM];
     char ExtrPath[NM];
+    wchar ExtrPathW[NM];
     char CommentFile[NM];
     char ArcPath[NM];
     char Password[MAXPASSWORD];
@@ -64,6 +66,8 @@ class RAROptions
     PathExclMode ExclPath;
     int Recurse;
     Int64 VolSize;
+    Array<Int64> NextVolSizes;
+    int CurVolNum;
     bool AllYes;
     bool DisableViewAV;
     bool DisableSortSolid;
@@ -83,6 +87,7 @@ class RAROptions
     char GenerateMask[80];
     bool ProcessEA;
     bool SaveStreams;
+    bool SetCompressedAttr;
     uint FileTimeOlder;
     uint FileTimeNewer;
     RarTime FileTimeBefore;
@@ -101,10 +106,13 @@ class RAROptions
     EXTTIME_MODE xctime;
     EXTTIME_MODE xatime;
     EXTTIME_MODE xarctime;
+    char CompressStdin[NM];
+
 
 
 #ifdef RARDLL
     char DllDestName[NM];
+    wchar DllDestNameW[NM];
     int DllOpMode;
     int DllError;
     LONG UserData;
