@@ -23,7 +23,8 @@ void GetFilePath(const char *FullName,char *Path);
 void GetFilePath(const wchar *FullName,wchar *Path);
 void RemoveNameFromPath(char *Path);
 void RemoveNameFromPath(wchar *Path);
-void GetConfigName(const char *Name,char *FullName);
+bool EnumConfigPaths(char *Path,int Number);
+void GetConfigName(const char *Name,char *FullName,bool CheckExist);
 char* GetVolNumPart(char *ArcName);
 void NextVolumeName(char *ArcName,bool OldNumbering);
 bool IsNameUsable(const char *Name);
@@ -37,4 +38,8 @@ int ParseVersionFileName(char *Name,wchar *NameW,bool Truncate);
 char* VolNameToFirstName(const char *VolName,char *FirstName,bool NewNumbering);
 
 
+wchar* GetWideName(const char *Name,const wchar *NameW,wchar *DestW);
+
+inline char* GetOutputName(const char *Name) {return((char *)Name);};
+
 #endif
