@@ -16,6 +16,8 @@ class ScanTree
     FindFile *FindStack[MAXSCANDEPTH];
     int Depth;
 
+    int SetAllMaskDepth;
+
     StringList *FileMasks;
     int Recurse;
     bool GetLinks;
@@ -24,10 +26,14 @@ class ScanTree
 
     char CurMask[NM];
     wchar CurMaskW[NM];
+    char OrigCurMask[NM];
+    wchar OrigCurMaskW[NM];
     bool SearchAllInRoot;
     bool FastFindFile;
     int SpecPathLength;
     int SpecPathLengthW;
+
+    char ErrArcName[NM];
   public:
     ScanTree(StringList *FileMasks,int Recurse,bool GetLinks,int GetDirs);
     ~ScanTree();
@@ -35,6 +41,7 @@ class ScanTree
     int GetSpecPathLength() {return(SpecPathLength);};
     int GetSpecPathLengthW() {return(SpecPathLengthW);};
     int GetErrors() {return(Errors);};
+    void SetErrArcName(const char *Name) {strcpy(ErrArcName,Name);}
 };
 
 #endif
