@@ -18,6 +18,16 @@ RarTime& RarTime::operator =(FILETIME &ft)
   rlt.Hour=st.wHour;
   rlt.Minute=st.wMinute;
   rlt.Second=st.wSecond;
+  rlt.wDay=st.wDayOfWeek;
+  rlt.yDay=rlt.Day-1;
+  for (int I=1;I<rlt.Month;I++)
+  {
+    static int mdays[12]={31,28,31,30,31,30,31,31,30,31,30,31};
+    rlt.yDay+=mdays[I-1];
+  }
+  if (rlt.Month>2 && IsLeapYear(rlt.Year))
+    rlt.yDay++;
+
   st.wMilliseconds=0;
   SystemTimeToFileTime(&st,&zft);
   rlt.Reminder=lft.dwLowDateTime-zft.dwLowDateTime;
@@ -58,6 +68,8 @@ RarTime& RarTime::operator =(time_t ut)
   rlt.Minute=t->tm_min;
   rlt.Second=t->tm_sec;
   rlt.Reminder=0;
+  rlt.wDay=t->tm_wday;
+  rlt.yDay=t->tm_yday;
   return(*this);
 }
 
@@ -80,6 +92,8 @@ time_t RarTime::GetUnix()
 
 Int64 RarTime::GetRaw()
 {
+  if (!IsSet())
+    return(0);
 #ifdef _WIN_32
   FILETIME ft;
   GetWin32(&ft);
@@ -104,7 +118,7 @@ void RarTime::SetRaw(Int64 RawTime)
 #elif defined(_UNIX) || defined(_EMX)
   time_t ut=int64to32(RawTime/10000000);
   *this=ut;
-  rlt.Reminder=RawTime%10000000;
+  rlt.Reminder=int64to32(RawTime%10000000);
 #endif
 }
 #endif
@@ -112,7 +126,10 @@ void RarTime::SetRaw(Int64 RawTime)
 
 bool RarTime::operator == (RarTime &rt)
 {
-  return(memcmp(&rlt,&rt.rlt,sizeof(rlt))==0);
+  return(rlt.Year==rt.rlt.Year && rlt.Month==rt.rlt.Month &&
+         rlt.Day==rt.rlt.Day && rlt.Hour==rt.rlt.Hour &&
+         rlt.Minute==rt.rlt.Minute && rlt.Second==rt.rlt.Second &&
+         rlt.Reminder==rt.rlt.Reminder);
 }
 
 
@@ -236,7 +253,9 @@ void RarTime::SetCurrentTime()
 {
 #ifdef _WIN_32
   FILETIME ft;
-  GetSystemTimeAsFileTime(&ft);
+  SYSTEMTIME st;
+  GetSystemTime(&st);
+  SystemTimeToFileTime(&st,&ft);
   *this=ft;
 #else
   time_t st;
@@ -247,7 +266,7 @@ void RarTime::SetCurrentTime()
 #endif
 
 
-#ifndef SFX_MODULE
+#if !defined(SFX_MODULE) && !defined(_WIN_CE)
 const char *GetMonthName(int Month)
 {
 #ifdef SILENT
@@ -263,3 +282,7 @@ const char *GetMonthName(int Month)
 #endif
 
 
+bool IsLeapYear(int Year)
+{
+  return((Year&3)==0 && (Year%100!=0 || Year%400==0));
+}
