@@ -1,5 +1,9 @@
 #include "rar.hpp"
 
+#if defined(_EMX) && !defined(_DJGPP)
+#include "unios2.cpp"
+#endif
+
 void WideToChar(const wchar *Src,char *Dest,int DestSize)
 {
 #ifdef _WIN_32
@@ -12,12 +16,21 @@ void WideToChar(const wchar *Src,char *Dest,int DestSize)
   if (wcstombs(Dest,Src,DestSize)==-1)
     *Dest=0;
 #else
-  for (int I=0;I<DestSize;I++)
+  if (UnicodeEnabled())
   {
-    Dest[I]=(char)Src[I];
-    if (Src[I]==0)
-      break;
+#if defined(_EMX) && !defined(_DJGPP)
+    int len=Min(strlenw(Src),DestSize-1);
+    uni_fromucs((UniChar*)Src,len,Dest,(size_t*)&DestSize);
+    Dest[len]=0;
+#endif
   }
+  else
+    for (int I=0;I<DestSize;I++)
+    {
+      Dest[I]=(char)Src[I];
+      if (Src[I]==0)
+        break;
+    }
 #endif
 #endif
 #endif
@@ -35,12 +48,21 @@ void CharToWide(const char *Src,wchar *Dest,int DestSize)
 #ifdef MBFUNCTIONS
   mbstowcs(Dest,Src,DestSize);
 #else
-  for (int I=0;I<DestSize;I++)
+  if (UnicodeEnabled())
   {
-    Dest[I]=(wchar_t)Src[I];
-    if (Src[I]==0)
-      break;
+#if defined(_EMX) && !defined(_DJGPP)
+    int len=Min(strlen(Src),DestSize-1);
+    uni_toucs((char*)Src,len,(UniChar*)Dest,(size_t*)&DestSize);
+    Dest[len]=0;
+#endif
   }
+  else
+    for (int I=0;I<DestSize;I++)
+    {
+      Dest[I]=(wchar_t)Src[I];
+      if (Src[I]==0)
+        break;
+    }
 #endif
 #endif
 #endif
@@ -133,6 +155,20 @@ void UtfToWide(const char *Src,wchar *Dest,int DestSize)
 #endif
 
 
+bool UnicodeEnabled()
+{
+#ifdef UNICODE_SUPPORTED
+  #ifdef _EMX
+    return(uni_ready);
+  #else
+    return(true);
+  #endif
+#else
+  return(false);
+#endif
+}
+
+
 int strlenw(const wchar *str)
 {
   int length=0;
@@ -217,27 +253,15 @@ int strncmpw(const wchar *s1,const wchar *s2,int n)
 #ifndef SFX_MODULE
 int stricmpw(const wchar *s1,const wchar *s2)
 {
-#ifdef _WIN_32
-  if (WinNT())
-    return(CompareStringW(LOCALE_USER_DEFAULT,NORM_IGNORECASE|SORT_STRINGSORT,s1,-1,s2,-1)-2);
-  else
-  {
-    char Ansi1[NM*sizeof(wchar)],Ansi2[NM*sizeof(wchar)];
-    WideToChar(s1,Ansi1,sizeof(Ansi1));
-    WideToChar(s2,Ansi2,sizeof(Ansi2));
-    return(stricomp(Ansi1,Ansi2));
-  }
-#else
   char Ansi1[NM*sizeof(wchar)],Ansi2[NM*sizeof(wchar)];
   WideToChar(s1,Ansi1,sizeof(Ansi1));
   WideToChar(s2,Ansi2,sizeof(Ansi2));
   return(stricomp(Ansi1,Ansi2));
-#endif
 }
 #endif
 
 
-#ifndef SFX_MODULE
+#if !defined(SFX_MODULE) && !defined(_WIN_CE)
 inline int strnicmpw_w2c(const wchar *s1,const wchar *s2,int n)
 {
   wchar Wide1[NM*2],Wide2[NM*2];
@@ -250,22 +274,13 @@ inline int strnicmpw_w2c(const wchar *s1,const wchar *s2,int n)
   WideToChar(Wide2,Ansi2,sizeof(Ansi2));
   return(stricomp(Ansi1,Ansi2));
 }
+#endif
 
 
+#ifndef SFX_MODULE
 int strnicmpw(const wchar *s1,const wchar *s2,int n)
 {
-#ifdef _WIN_32
-  if (WinNT())
-  {
-    int Length1=Min(strlenw(s1),n);
-    int Length2=Min(strlenw(s2),n);
-    return(CompareStringW(LOCALE_USER_DEFAULT,NORM_IGNORECASE|SORT_STRINGSORT,s1,Length1,s2,Length2)-2);
-  }
-  else
-    return(strnicmpw_w2c(s1,s2,n));
-#else
   return(strnicmpw_w2c(s1,s2,n));
-#endif
 }
 #endif
 
@@ -306,21 +321,9 @@ wchar* strpbrkw(const wchar *s1,const wchar *s2)
 #ifndef SFX_MODULE
 wchar* strlowerw(wchar *Str)
 {
-#ifdef _WIN_32
-  if (WinNT())
-    CharLowerW(Str);
-  else
-  {
-    char AnsiStr[NM*sizeof(wchar)];
-    WideToChar(Str,AnsiStr,sizeof(AnsiStr));
-    strlower(AnsiStr);
-    CharToWide(AnsiStr,Str);
-  }
-#else
   for (wchar *ChPtr=Str;*ChPtr;ChPtr++)
     if (*ChPtr<128)
       *ChPtr=loctolower(*ChPtr);
-#endif
   return(Str);
 }
 #endif
@@ -329,21 +332,9 @@ wchar* strlowerw(wchar *Str)
 #ifndef SFX_MODULE
 wchar* strupperw(wchar *Str)
 {
-#ifdef _WIN_32
-  if (WinNT())
-    CharUpperW(Str);
-  else
-  {
-    char AnsiStr[NM*sizeof(wchar)];
-    WideToChar(Str,AnsiStr,sizeof(AnsiStr));
-    strupper(AnsiStr);
-    CharToWide(AnsiStr,Str);
-  }
-#else
   for (wchar *ChPtr=Str;*ChPtr;ChPtr++)
     if (*ChPtr<128)
       *ChPtr=loctoupper(*ChPtr);
-#endif
   return(Str);
 }
 #endif
@@ -352,25 +343,7 @@ wchar* strupperw(wchar *Str)
 #ifndef SFX_MODULE
 int toupperw(int ch)
 {
-#ifdef _WIN_32
-  if (WinNT())
-    return((int)CharUpperW((wchar *)ch));
-  else
-  {
-    char AnsiStr[10];
-    wchar WideStr[10];
-    WideStr[0]=ch;
-    WideStr[1]=0;
-    WideToChar(WideStr,AnsiStr,sizeof(AnsiStr));
-    if (*AnsiStr=='?')
-      return(ch);
-    *AnsiStr=loctoupper(*AnsiStr);
-    CharToWide(AnsiStr,WideStr);
-    return(*WideStr);
-  }
-#else
   return((ch<128) ? loctoupper(ch):ch);
-#endif
 }
 #endif
 
@@ -412,6 +385,21 @@ char* SupportDBCS::charnext(const char *s)
 }
 
 
+uint SupportDBCS::strlend(const char *s)
+{
+  uint Length=0;
+  while (*s!=0)
+  {
+    if (IsLeadByte[*s])
+      s+=2;
+    else
+      s++;
+    Length++;
+  }
+  return(Length);
+}
+
+
 char* SupportDBCS::strchrd(const char *s, int c)
 {
   while (*s!=0)
