@@ -5,7 +5,7 @@
 #define MBFUNCTIONS
 #endif
 
-#if defined(MBFUNCTIONS) || defined(_WIN_32)
+#if defined(MBFUNCTIONS) || defined(_WIN_32) || defined(_EMX) && !defined(_DJGPP)
 #define UNICODE_SUPPORTED
 #endif
 
@@ -13,12 +13,19 @@
 #define DBCS_SUPPORTED
 #endif
 
+#ifdef _EMX
+int uni_init(int codepage);
+int uni_done();
+#endif
+
 void WideToChar(const wchar *Src,char *Dest,int DestSize=0x10000000);
 void CharToWide(const char *Src,wchar *Dest,int DestSize=0x10000000);
 byte* WideToRaw(const wchar *Src,byte *Dest,int DestSize=0x10000000);
 wchar* RawToWide(const byte *Src,wchar *Dest,int DestSize=0x10000000);
 void WideToUtf(const wchar *Src,char *Dest,int DestSize);
 void UtfToWide(const char *Src,wchar *Dest,int DestSize);
+bool UnicodeEnabled();
+
 int strlenw(const wchar *str);
 wchar* strcpyw(wchar *dest,const wchar *src);
 wchar* strncpyw(wchar *dest,const wchar *src,int n);
@@ -44,6 +51,7 @@ class SupportDBCS
     void Init();
 
     char* charnext(const char *s);
+    uint strlend(const char *s);
     char *strchrd(const char *s, int c);
     char *strrchrd(const char *s, int c);
     void copychrd(char *dest,const char *src);
@@ -55,6 +63,7 @@ class SupportDBCS
 extern SupportDBCS gdbcs;
 
 inline char* charnext(const char *s) {return (char *)(gdbcs.DBCSMode ? gdbcs.charnext(s):s+1);}
+inline uint strlend(const char *s) {return (gdbcs.DBCSMode ? gdbcs.strlend(s):strlen(s));}
 inline char* strchrd(const char *s, int c) {return (char *)(gdbcs.DBCSMode ? gdbcs.strchrd(s,c):strchr(s,c));}
 inline char* strrchrd(const char *s, int c) {return (char *)(gdbcs.DBCSMode ? gdbcs.strrchrd(s,c):strrchr(s,c));}
 inline void copychrd(char *dest,const char *src) {if (gdbcs.DBCSMode) gdbcs.copychrd(dest,src); else *dest=*src;}
@@ -63,6 +72,7 @@ inline void InitDBCS() {gdbcs.Init();}
 
 #else
 #define charnext(s) ((s)+1)
+#define strlend strlen
 #define strchrd strchr
 #define strrchrd strrchr
 #define IsDBCSMode() (true)
