@@ -189,11 +189,14 @@ void Unpack::Unpack29(bool Solid)
       return;
   }
 
+  if (PPMError)
+    return;
+
   while (true)
   {
     UnpPtr&=MAXWINMASK;
 
-    if (InAddr>ReadTop-30)
+    if (InAddr>ReadBorder)
     {
       if (!UnpReadBuf())
         break;
@@ -213,7 +216,10 @@ void Unpack::Unpack29(bool Solid)
     {
       int Ch=PPM.DecodeChar();
       if (Ch==-1)
+      {
+        PPMError=true;
         break;
+      }
       if (Ch==PPMEscChar)
       {
         int NextCh=PPM.DecodeChar();
@@ -343,7 +349,8 @@ void Unpack::Unpack29(bool Solid)
     }
     if (Number==258)
     {
-      CopyString(LastLength,LastDist);
+      if (LastLength!=0)
+        CopyString(LastLength,LastDist);
       continue;
     }
     if (Number<263)
@@ -434,12 +441,27 @@ bool Unpack::ReadVMCode()
 bool Unpack::ReadVMCodePPM()
 {
   unsigned int FirstByte=PPM.DecodeChar();
+  if ((int)FirstByte==-1)
+    return(false);
   int Length=(FirstByte & 7)+1;
   if (Length==7)
-    Length=PPM.DecodeChar()+7;
+  {
+    int B1=PPM.DecodeChar();
+    if (B1==-1)
+      return(false);
+    Length=B1+7;
+  }
   else
     if (Length==8)
-      Length=PPM.DecodeChar()*256+PPM.DecodeChar();
+    {
+      int B1=PPM.DecodeChar();
+      if (B1==-1)
+        return(false);
+      int B2=PPM.DecodeChar();
+      if (B2==-1)
+        return(false);
+      Length=B1*256+B2;
+    }
   Array<byte> VMCode(Length);
   for (int I=0;I<Length;I++)
   {
@@ -603,10 +625,11 @@ bool Unpack::UnpReadBuf()
     ReadTop=DataSize;
   }
   else
-    DataSize=InAddr;
+    DataSize=ReadTop;
   int ReadCode=UnpIO->UnpRead(InBuf+DataSize,(BitInput::MAX_SIZE-DataSize)&~0xf);
   if (ReadCode>0)
     ReadTop+=ReadCode;
+  ReadBorder=ReadTop-30;
   return(ReadCode!=-1);
 }
 
@@ -857,9 +880,10 @@ void Unpack::UnpInitData(int Solid)
     InitFilters();
   }
   InitBitInput();
+  PPMError=false;
   WrittenFileSize=0;
   ReadTop=0;
-
+  ReadBorder=0;
 #ifndef SFX_MODULE
   UnpInitData20(Solid);
 #endif
