@@ -30,10 +30,22 @@ bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,char Comman
 #if !defined(SFX_MODULE) && !defined(RARDLL)
   bool RecoveryDone=false;
 #endif
-  bool FailedOpen=false;
+  bool FailedOpen=false,OldSchemeTested=false;
 
   while (!Arc.Open(NextName))
   {
+    if (!OldSchemeTested)
+    {
+      char AltNextName[NM];
+      strcpy(AltNextName,Arc.FileName);
+      NextVolumeName(AltNextName,true);
+      OldSchemeTested=true;
+      if (Arc.Open(AltNextName))
+      {
+        strcpy(NextName,AltNextName);
+        break;
+      }
+    }
 #ifdef RARDLL
     if (Cmd->Callback==NULL && Cmd->ChangeVolProc==NULL ||
         Cmd->Callback!=NULL && Cmd->Callback(UCM_CHANGEVOLUME,Cmd->UserData,(LONG)NextName,RAR_VOL_ASK)==-1)
@@ -44,9 +56,13 @@ bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,char Comman
     }
     if (Cmd->ChangeVolProc!=NULL)
     {
+#ifdef _WIN_32
       _EBX=_ESP;
+#endif
       int RetCode=Cmd->ChangeVolProc(NextName,RAR_VOL_ASK);
+#ifdef _WIN_32
       _ESP=_EBX;
+#endif
       if (RetCode==0)
       {
         Cmd->DllError=ERAR_EOPEN;
@@ -56,7 +72,7 @@ bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,char Comman
     }
 #else
 
-#ifndef SFX_MODULE
+#if !defined(SFX_MODULE) && !defined(_WIN_CE)
     if (!RecoveryDone)
     {
       RecVolumes RecVol;
@@ -96,9 +112,13 @@ bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,char Comman
     return(false);
   if (Cmd->ChangeVolProc!=NULL)
   {
+#ifdef _WIN_32
     _EBX=_ESP;
+#endif
     int RetCode=Cmd->ChangeVolProc(NextName,RAR_VOL_NOTIFY);
+#ifdef _WIN_32
     _ESP=_EBX;
+#endif
     if (RetCode==0)
       return(false);
   }
